<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl" sourcelanguage="en">
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Selecteer taal:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Systeem Taal&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Aantekening</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Herstart programma als je van taal wisselt.</translation>
    </message>
</context>
<context>
    <name>Report</name>
    <message>
        <source>Time Sheet Report</source>
        <translation>Urenregistratie rapport</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Naam:</translation>
    </message>
    <message>
        <source>Company:</source>
        <translation>Bedrijf:</translation>
    </message>
    <message>
        <source>Address:</source>
        <translation>Adres:</translation>
    </message>
    <message>
        <source>Phone:</source>
        <translation>Telefoon:</translation>
    </message>
    <message>
        <source>Fax:</source>
        <translation>Fax:</translation>
    </message>
    <message>
        <source>Email:</source>
        <translation>Email:</translation>
    </message>
    <message>
        <source>Website:</source>
        <translation>Website:</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message>
        <source>Prepend currency symbol</source>
        <translation>Plaatst u valutateken</translation>
    </message>
    <message>
        <source>Hourly rate:</source>
        <translation>Uur loon:</translation>
    </message>
    <message>
        <source>Tax rate:</source>
        <translation>Belastingtarief:</translation>
    </message>
    <message>
        <source>Currency symbol:</source>
        <translation>Munteenheid:</translation>
    </message>
    <message>
        <source>Contact Information</source>
        <translation>Contact informatie</translation>
    </message>
    <message>
        <source>Data</source>
        <translation>Gegevens</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation>Voorbeeld</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exporteer</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Afdrukken</translation>
    </message>
    <message>
        <source>Web Page (*.html *.htm)</source>
        <translation>Web Pagina (*.html *.htm)</translation>
    </message>
    <message>
        <source>iCalendar (*.ics)</source>
        <translation>ICalendar (*.ics)</translation>
    </message>
    <message>
        <source>Outlook CSV (*.csv)</source>
        <translation>Outlook CSV (*.csv)</translation>
    </message>
    <message>
        <source>Export Report</source>
        <translation>Exporteer Raport</translation>
    </message>
    <message>
        <source>View Reports</source>
        <translation>Bekijk Rapporten</translation>
    </message>
    <message>
        <source>Create Report</source>
        <translation>Maak Rapport</translation>
    </message>
    <message>
        <source>Phone: %1</source>
        <translation>Telefoon: %1</translation>
    </message>
    <message>
        <source>Fax: %1</source>
        <translation>Fax: %1</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Uren</translation>
    </message>
    <message>
        <source>Subtotal</source>
        <translation>Subtotaal</translation>
    </message>
    <message>
        <source>Taxes</source>
        <translation>Belasting</translation>
    </message>
    <message>
        <source>Total</source>
        <translation>Totaal</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation>
            <numerusform>%n uur</numerusform>
            <numerusform>%n uren</numerusform>
        </translation>
    </message>
    <message>
        <source>%L1 hours</source>
        <translation>%L1 uren</translation>
    </message>
</context>
<context>
    <name>SessionDelegate</name>
    <message>
        <source>Error</source>
        <translation type="unfinished">Fout</translation>
    </message>
    <message>
        <source>Session conflicts with other sessions.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SessionDialog</name>
    <message>
        <source>Add Session</source>
        <translation>Voeg een sessie toe</translation>
    </message>
    <message>
        <source>Date:</source>
        <translation>Datum:</translation>
    </message>
    <message>
        <source>Start:</source>
        <translation>Start:</translation>
    </message>
    <message>
        <source>Stop:</source>
        <translation>Stop:</translation>
    </message>
    <message>
        <source>Task:</source>
        <translation>Taak:</translation>
    </message>
    <message>
        <source>Edit Session</source>
        <translation>Bewerk Sessie</translation>
    </message>
</context>
<context>
    <name>SessionModel</name>
    <message>
        <source>Total</source>
        <translation type="unfinished">Totaal</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start</source>
        <translation type="unfinished">Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="unfinished">Stop</translation>
    </message>
    <message>
        <source>Task</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hours</source>
        <translation type="unfinished">Uren</translation>
    </message>
    <message>
        <source>Daily</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Weekly</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Monthly</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Report</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>00:00:00</source>
        <translation>00:00:00</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleer</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Project</source>
        <translation>&amp;Taak</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Toevoegen</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Verwijderen</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Delete</source>
        <translation>Ctrl+Shift+Delete</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Einde</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Session</source>
        <translation>&amp;Sessie</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Bewerk</translation>
    </message>
    <message>
        <source>Ctrl+Delete</source>
        <translation>Ctrl+Delete</translation>
    </message>
    <message>
        <source>S&amp;ettings</source>
        <translation>I&amp;nstellingen</translation>
    </message>
    <message>
        <source>Columns</source>
        <translation>Kolommen</translation>
    </message>
    <message>
        <source>&amp;Decimal Totals</source>
        <translation>&amp;Aantal komma&apos;s</translation>
    </message>
    <message>
        <source>&amp;Inline Editing</source>
        <translation>&amp;Inline Bewerken</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Toepassing &amp;Taal...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Help</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Over</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Over &amp;Qt</translation>
    </message>
    <message>
        <source>Project</source>
        <translation>Taak</translation>
    </message>
    <message>
        <source>Timer</source>
        <translation>Tijdklok</translation>
    </message>
    <message>
        <source>Show all</source>
        <translation>Toon alles</translation>
    </message>
    <message>
        <source>Show only unbilled</source>
        <translation>Toon alleen de te factureren</translation>
    </message>
    <message>
        <source>Show only this year</source>
        <translation>Toon alleen dit jaar</translation>
    </message>
    <message>
        <source>Show only this month</source>
        <translation>Toon alleen deze maand</translation>
    </message>
    <message>
        <source>Show only this week</source>
        <translation>Toon alleen deze week</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Auteursrecht &amp;copy; 2008 2012 Graeme Gott {2008-%1 ?}</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Uitgebracht onder het  &lt;a href=%1&gt;GPL 3&lt;/a&gt; licentie</translation>
    </message>
    <message>
        <source>Session conflicts with other sessions.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Restore</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to read time data.</source>
        <translation>Kan de tijdgegevens niet lezen.</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Naamloos</translation>
    </message>
    <message>
        <source>Unable to write time data.</source>
        <translation>Kan de tijdgegevens niet schrijven.</translation>
    </message>
    <message>
        <source>There are timers running. Stop timers and quit?</source>
        <translation>Er lopen tijdklokken. Stop de tijdklok en stop?</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Over</translation>
    </message>
    <message>
        <source>A program to help track spent time</source>
        <translation>Een programma dat de tijd bij houdt</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Vraag</translation>
    </message>
    <message>
        <source>&amp;Create Report...</source>
        <translation>&amp;Maak Rapport...</translation>
    </message>
    <message>
        <source>View R&amp;eports</source>
        <translation>Bekijk R&amp;apporten</translation>
    </message>
    <message>
        <source>Cancel this session?</source>
        <translation>Annuleer deze sessie?</translation>
    </message>
    <message>
        <source>Add Project</source>
        <translation>Taak toevoegen</translation>
    </message>
    <message>
        <source>Enter project name:</source>
        <translation>Voer naam van taak in:</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <source>Unable to create time data location.</source>
        <translation>Kan geen tijd of data locatie creëren.</translation>
    </message>
    <message>
        <source>Unable to move time data location.</source>
        <translation>Kan de tijd of data locatie niet verplaatsen.</translation>
    </message>
    <message>
        <source>A project with that name already exists.</source>
        <translation>Een taak met deze naam bestaat al.</translation>
    </message>
    <message>
        <source>Remove selected project?</source>
        <translation>Verwijder geselecteerde taak?</translation>
    </message>
    <message>
        <source>Remove selected session?</source>
        <translation>Verwijder geselecteerde sessie?</translation>
    </message>
    <message numerus="yes">
        <source>%n timer(s) running</source>
        <translation>
            <numerusform>%n timer running</numerusform>
            <numerusform>%n timers running</numerusform>
        </translation>
    </message>
    <message>
        <source>Kapow Punch Clock</source>
        <translation>Kapow Stempel klok</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Punch clock program</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Store settings as INI format in specified file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do not create automatic backups of time data.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The time data file to use.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
